@@ -43,10 +43,29 @@ sub set_query {
   }
 }
 
+sub get_mset {
+  my $self = shift;
+  my $nargs = scalar(@_);
+  if( $nargs == 3 ) {
+    my $type = ref( $_[2] );
+    if ( $type eq 'CODE' ) {
+      # get_mset(first, max, matchdecider) [perl extra]
+      splice @_, 2, 0, (0, 0);
+    } elsif ( $type eq 'Search::Xapian::RSet' ) {
+      # get_mset(first, max, rset)
+      splice @_, 2, 0, (0);
+    }
+  } elsif( $nargs == 4 && ref( $_[3] ) eq 'CODE' ) {
+    # get_mset(first, max, rset, matchdecider)
+    splice @_, 2, 0, (0);
+  }
+  return $self->get_mset1( @_ );
+}
+
 sub matches {
-  my ($self, $start, $size) = @_;
+  my $self = shift;
   my @array;
-  tie( @array, 'Search::Xapian::MSet::Tied', $self->get_mset($start, $size) );
+  tie( @array, 'Search::Xapian::MSet::Tied', $self->get_mset(@_) );
   return @array;
 }
 
@@ -105,10 +124,11 @@ constructor, together with any other passed arguments.
 
 =item get_query
 
-=item matches <start> <size>
+=item matches <start> <size> [<check_at_least>]
 
-Takes the start element, and maximum number of elements, and
-returns an array tied to L<Search::Xapian::MSet::Tied>. 
+Takes the start element, and maximum number of elements (and optionally
+the minimum number of matches to check), and returns an array tied to
+L<Search::Xapian::MSet::Tied>. 
 
 =item get_matching_terms_begin
 
